# malwarescan/app.py
from flask_appfactory.app import load_config, load_application


def create_app(load=True, **kwargs_config):
    # PRODUCTION
    import logging
    import logging.config
    from libs import encoder
    from flask import Flask
    from libs.helpers import ReverseProxied, fltr_elapsedTime, fltr_elapsedTime_secs
    flask_app = Flask(
        __name__,
        static_folder='static',
        static_url_path='/static',
        template_folder='templates')
    flask_app.json_encoder = encoder.JSONEncoder
    load_config(flask_app, 'malwarescan.config', **kwargs_config)
    logging.config.dictConfig(flask_app.config['APP_LOG'])
    flask_app.wsgi_app = ReverseProxied(flask_app.wsgi_app)
    # Set some Jinja2 variables
    flask_app.jinja_env.trim_blocks = True
    flask_app.jinja_env.lstrip_blocks = True
    flask_app.jinja_env.filters['elapsedTime'] = fltr_elapsedTime
    flask_app.jinja_env.filters['elapsedTimeSecs'] = fltr_elapsedTime_secs
    if load is True:
        load_application(flask_app)
    # Dirty 'plug' of admin extension
    if "mods.admin" in flask_app.config['PACKAGES']:
        from mods.admin.views import admin
        admin.init_app(flask_app)
    return flask_app


def run_apis():
    flsk_app = create_app()
    flsk_app.run(
        flsk_app.config['FLASK_HOST'], port=flsk_app.config['FLASK_PORT'])


if __name__ == "__main__":
    run_apis()
